==> jboss-eap-6.4.17-src.zip: jboss-eap-6.4-src/naming/src/main/java/org/jboss/as/naming/subsystem/RemoteNamingRemove.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.naming.subsystem;

import org.jboss.as.controller.ServiceRemoveStepHandler;
import org.jboss.as.naming.remote.RemoteNamingServerService;
import org.jboss.msc.service.ServiceName;

/**
 * Handles removing a JNDI binding
 */
public class RemoteNamingRemove extends ServiceRemoveStepHandler {

    public static final RemoteNamingRemove INSTANCE = new RemoteNamingRemove();

    private RemoteNamingRemove() {
        super(RemoteNamingAdd.INSTANCE);
    }

    @Override
    protected ServiceName serviceName(final String name) {
        return RemoteNamingServerService.SERVICE_NAME;
    }
}

==> jboss-eap-7.1.1-src.zip: jboss-eap-7.1-src/naming/src/main/java/org/jboss/as/naming/subsystem/RemoteNamingRemove.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.naming.subsystem;

import org.jboss.as.controller.ServiceRemoveStepHandler;
import org.jboss.as.naming.remote.RemoteNamingServerService;
import org.jboss.msc.service.ServiceName;

/**
 * Handles removing a JNDI binding
 */
public class RemoteNamingRemove extends ServiceRemoveStepHandler {

    public static final RemoteNamingRemove INSTANCE = new RemoteNamingRemove();

    private RemoteNamingRemove() {
        super(RemoteNamingAdd.INSTANCE, RemoteNamingResourceDefinition.REMOTE_NAMING_CAPABILITY);
    }

    @Override
    protected ServiceName serviceName(final String name) {
        return RemoteNamingServerService.SERVICE_NAME;
    }
}
